/*
 * Copyright 2019 The Starlark in Rust Authors.
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

pub mod any;
pub mod array;
pub mod bigint;
pub mod bool;
pub mod dict;
pub mod enumeration;
pub mod float;
pub mod function;
pub mod int;
pub(crate) mod known_methods;
pub mod list;
pub mod none;
pub mod range;
pub mod record;
pub mod regex;
pub mod string;
pub mod structs;
pub mod tuple;
pub(crate) mod unbound;
